package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.Coupons;
import com.ruoyi.system.domain.CouponUser;

/**
 * 优惠券Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-16
 */
public interface CouponsMapper
{
    /**
     * 查询优惠券
     *
     * @param id 优惠券主键
     * @return 优惠券
     */
    public Coupons selectCouponsById(Long id);

    /**
     * 查询优惠券列表
     *
     * @param coupons 优惠券
     * @return 优惠券集合
     */
    public List<Coupons> selectCouponsList(Coupons coupons);

    /**
     * 新增优惠券
     *
     * @param coupons 优惠券
     * @return 结果
     */
    public int insertCoupons(Coupons coupons);

    /**
     * 修改优惠券
     *
     * @param coupons 优惠券
     * @return 结果
     */
    public int updateCoupons(Coupons coupons);

    /**
     * 删除优惠券
     *
     * @param id 优惠券主键
     * @return 结果
     */
    public int deleteCouponsById(Long id);

    /**
     * 批量删除优惠券
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCouponsByIds(Long[] ids);

    /**
     * 批量删除优惠券领取记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCouponUserByCouponIds(Long[] ids);

    /**
     * 批量新增优惠券领取记录
     *
     * @param couponUserList 优惠券领取记录列表
     * @return 结果
     */
    public int batchCouponUser(List<CouponUser> couponUserList);


    /**
     * 通过优惠券主键删除优惠券领取记录信息
     *
     * @param id 优惠券ID
     * @return 结果
     */
    public int deleteCouponUserByCouponId(Long id);
}
